Struct curve25519_dalek::backend::vector::avx2::edwards::CachedPoint [−][src]
pub struct CachedPoint(pub(super) FieldElement2625x4);simd_backend and (target features avx2 or avx512ifma) and target feature avx2 and non-target feature avx512ifma only.Expand description
Tuple Fields
0: FieldElement2625x4Trait Implementations
Add an ExtendedPoint and a CachedPoint.
type Output = ExtendedPoint
type Output = ExtendedPoint
The resulting type after applying the + operator.
Returns the “default value” for a type. Read more
Performs the conversion.
Returns the identity element of the curve. Can be used as a constructor. Read more
Lazily negate the point.
Warning
Because this method does not perform a reduction, it is not safe to repeatedly negate a point.
type Output = CachedPoint
type Output = CachedPoint
The resulting type after applying the - operator.
Implement subtraction by negating the point and adding.
Empirically, this seems about the same cost as a custom subtraction impl (maybe because the benefit is cancelled by increased code size?)
type Output = ExtendedPoint
type Output = ExtendedPoint
The resulting type after applying the - operator.